## Installation
Prerequisites: 
- Python >= 3.7
- Torch & Torchvision
- Numpy 
- Matplotlib
- PIL (Pillow) 

To install Python packages: 
```bash
$ pip install torch
$ pip install torchvision
$ pip install numpy
$ pip install matplotlib
$ pip install Pillow
```

To install library: 
```bash
$ pip install multi-scale-expansion
```
